"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const _nextIteration_1 = require("./_nextIteration");
/**
 * Determines whether a sequence contains any elements.
 * If predicate is specified, determines whether any element of a sequence satisfies a condition.
 * @param source The IEnumerable<T> to check for emptiness or apply the predicate to.
 * @param predicate A function to test each element for a condition.
 */
function any(source, predicate) {
    if (predicate) {
        return any2(source, predicate);
    }
    else {
        return any1(source);
    }
}
exports.any = any;
const any1 = (source) => tslib_1.__awaiter(this, void 0, void 0, function* () {
    const dataFunc = source.dataFunc;
    let values;
    switch (dataFunc.type) {
        case 0 /* PromiseToArray */:
            values = yield dataFunc.generator();
            return values.length !== 0;
        case 1 /* ArrayOfPromises */:
            values = dataFunc.generator();
            return values.length !== 0;
        case 2 /* PromiseOfPromises */:
            values = yield dataFunc.generator();
            return values.length !== 0;
    }
});
const any2 = (source, predicate) => tslib_1.__awaiter(this, void 0, void 0, function* () {
    const dataFunc = _nextIteration_1.nextIteration(source, predicate);
    let values;
    switch (dataFunc.type) {
        case 0 /* PromiseToArray */:
            values = yield dataFunc.generator();
            return values.includes(true);
        case 1 /* ArrayOfPromises */:
            values = yield Promise.all(dataFunc.generator());
            return values.includes(true);
        case 2 /* PromiseOfPromises */:
            values = yield Promise.all(yield dataFunc.generator());
            return values.includes(true);
    }
});
