"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
/**
 * Determines whether all elements of a sequence satisfy a condition.
 * @param source An Iterable<T> that contains the elements to apply the predicate to.
 * @param predicate A function to test each element for a condition.
 * @returns ``true`` if every element of the source sequence passes the test in the specified predicate,
 * or if the sequence is empty; otherwise, ``false``.
 */
function allAsync(source, predicate) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        for (const item of source) {
            if ((yield predicate(item)) === false) {
                return false;
            }
        }
        return true;
    });
}
exports.allAsync = allAsync;
